@@ -1,19 +1,19 @@
+from __future__ import annotations
+
 import math
 from itertools import product
 from typing import (
     Iterable,
     Literal,
     Mapping,
-    Optional,
     Sequence,
-    Union,
 )
 
 import cupy as cp
-import cupyx as cpx
 import numpy as np
 import pandas as pd
 from anndata import AnnData
+from cupyx.scipy import sparse
 from cupyx.scipy.sparse import issparse as cpissparse
 from scipy.sparse import csc_matrix, issparse
 
@@ -130,22 +130,23 @@ def _check_tuple_needles(
 def ligrec(
     adata: AnnData,
     cluster_key: str,
-    clusters: Optional[list] = None,
-    interactions: Union[pd.DataFrame, Mapping, Sequence, None] = None,
+    *,
+    clusters: list | None = None,
+    interactions: pd.DataFrame | Mapping | Sequence | None = None,
     complex_policy: Literal["min", "all"] = "min",
     threshold: float = 0.01,
-    corr_method: Union[str, None] = None,
+    corr_method: str | None = None,
     corr_axis: Literal["interactions", "clusters"] = "clusters",
     alpha: float = 0.05,
     use_raw: bool = True,
     copy: bool = False,
-    key_added: Union[str, None] = None,
-    gene_symbols: Union[str, None] = None,
+    key_added: str | None = None,
+    gene_symbols: str | None = None,
     n_perms: int = 1000,
     interactions_params: dict = {},
     transmitter_params: dict = {"categories": "ligand"},
     receiver_params: dict = {"categories": "receptor"},
-) -> Optional[pd.DataFrame]:
+) -> pd.DataFrame | None:
     """\
     Perform the permutation test as described in [Efremova et al., 2020].
 
@@ -237,10 +238,10 @@ def ligrec(
     Otherwise, modifies the adata object with the following key:
         * :attr:`~anndata.AnnData.uns` `['{key_added}']` -
             the above mentioned dict.
+
     NaN p-values mark combinations for which the mean expression of one of the \
     interacting components was 0 or it didnt pass the threshold percentage of \
     cells being expressed within a given cluster.
-
     """
     # Get and Check interactions
     if interactions is None:
@@ -445,7 +446,7 @@ def ligrec(
     interactions_ = np.vectorize(lambda g: gene_mapper[g])(interactions.values)
 
     if issparse(mat):
-        data_cp = cpx.scipy.sparse.csr_matrix(mat.tocsr())
+        data_cp = sparse.csr_matrix(mat.tocsr())
     else:
         data_cp = cp.array(mat)
 
